@@ -1,7 +1,8 @@
-from .EstraHelp import *
 from .sfw import *
 from .nsfw import *
+from .errors import *
+from .help import Help
 
 __title__ = "Estrapy-API"
-__version__ = "0.1.5"
+__version__ = "0.1.6"
 __author__ = "Stawa"
